pitchtools.IntervalClass
========================

.. abjad-lineage:: abjad.tools.pitchtools.IntervalClass.IntervalClass

.. autoclass:: abjad.tools.pitchtools.IntervalClass.IntervalClass

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.IntervalClass.IntervalClass.number
      ~abjad.tools.pitchtools.IntervalClass.IntervalClass.__abs__
      ~abjad.tools.pitchtools.IntervalClass.IntervalClass.__eq__
      ~abjad.tools.pitchtools.IntervalClass.IntervalClass.__float__
      ~abjad.tools.pitchtools.IntervalClass.IntervalClass.__format__
      ~abjad.tools.pitchtools.IntervalClass.IntervalClass.__hash__
      ~abjad.tools.pitchtools.IntervalClass.IntervalClass.__int__
      ~abjad.tools.pitchtools.IntervalClass.IntervalClass.__ne__
      ~abjad.tools.pitchtools.IntervalClass.IntervalClass.__repr__
      ~abjad.tools.pitchtools.IntervalClass.IntervalClass.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.IntervalClass.IntervalClass.number
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.IntervalClass.IntervalClass.__abs__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClass.IntervalClass.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClass.IntervalClass.__float__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClass.IntervalClass.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClass.IntervalClass.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClass.IntervalClass.__int__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClass.IntervalClass.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClass.IntervalClass.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClass.IntervalClass.__str__
   :noindex:
